==> libreoffice-fresh-sdk-24.8.4-2-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings =
[
    [ "Settings", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#adff63c05cc6343dd0b45b09c484806f9", null ],
    [ "PrintSettings", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a34ed989a34ee371bcf09e0754d9b2b2e", null ],
    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "AddParaSpacingToTableCells", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a93d9377f71e98306577e0009f30d2ea2", null ],
    [ "AddParaTableSpacing", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a973e72a6708edcf6b76dfcf09248a71f", null ],
    [ "AddParaTableSpacingAtStart", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a8490730058f35cd43883b2ffe2499c58", null ],
    [ "AlignTabStopPosition", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a5bc4600489248fd8da0baa5901c32e8e", null ],
    [ "ChartAutoUpdate", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a10e36ee0d1c5cafe6e2fef6ece598e22", null ],
    [ "ConsiderTextWrapOnObjPos", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#aa23887d145c41a9b32fe331ad877f966", null ],
    [ "IsLabelDocument", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a6d7932ccd512a21693d8db7c4982e83e", null ],
    [ "MathBaselineAlignment", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#af1352e0bf4c59d497afb6418798830f4", null ],
    [ "SaveGlobalDocumentLinks", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a60f42890192063bf039ccc0331e276ca", null ],
    [ "UseFormerLineSpacing", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a7b393c34585ad69a35fc17bdb044eef6", null ],
    [ "UseFormerObjectPositioning", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a72480b5cc4715c57e10f6df6da15b326", null ]
];

==> libreoffice-fresh-sdk-25.2.5-2-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings =
[
    [ "com::sun::star::document::Settings", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#adff63c05cc6343dd0b45b09c484806f9", null ],
    [ "com::sun::star::text::PrintSettings", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a34ed989a34ee371bcf09e0754d9b2b2e", null ],
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "AddParaSpacingToTableCells", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a93d9377f71e98306577e0009f30d2ea2", null ],
    [ "AddParaTableSpacing", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a973e72a6708edcf6b76dfcf09248a71f", null ],
    [ "AddParaTableSpacingAtStart", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a8490730058f35cd43883b2ffe2499c58", null ],
    [ "AlignTabStopPosition", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a5bc4600489248fd8da0baa5901c32e8e", null ],
    [ "ChartAutoUpdate", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a10e36ee0d1c5cafe6e2fef6ece598e22", null ],
    [ "ConsiderTextWrapOnObjPos", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#aa23887d145c41a9b32fe331ad877f966", null ],
    [ "IsLabelDocument", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a6d7932ccd512a21693d8db7c4982e83e", null ],
    [ "MathBaselineAlignment", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#af1352e0bf4c59d497afb6418798830f4", null ],
    [ "SaveGlobalDocumentLinks", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a60f42890192063bf039ccc0331e276ca", null ],
    [ "UseFormerLineSpacing", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a7b393c34585ad69a35fc17bdb044eef6", null ],
    [ "UseFormerObjectPositioning", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html#a72480b5cc4715c57e10f6df6da15b326", null ]
];
